/*
  MonsterMotoShield.cpp - Library for driving the Monster Moto Shield.
  Released into the public domain.
*/

#include "Arduino.h"
#include "MonsterMotoShield.h"

MonsterMotoShieldClass::MonsterMotoShieldClass()
{
  isInit=false;
// INA: Clockwise input
  inApin[0] = 7;
  inApin[1] = 4;  
  
  // INB: Counter-clockwise input
  inBpin[0] = 8;
  inBpin[1] = 9;

  // PWM input
  pwmpin[0] = 5;
  pwmpin[1] = 6;

  // CS: Current sense ANALOG input
  cspin[0] = A2;
  cspin[1] = A3;

  // EN: Status of switches output (Analog pin)
  enpin[0] = A0;
  enpin[1] = A1;
}


void MonsterMotoShieldClass::begin()
{
  for (int i=0; i<2; i++)
  {
    pinMode(inApin[i], OUTPUT);
    pinMode(inBpin[i], OUTPUT);
    pinMode(pwmpin[i], OUTPUT);
  }
  isInit=true;
  motorsOff();
}

void MonsterMotoShieldClass::motorsOff()
{
  if(!isInit) return;
  motorGo(0, BRAKEGND, 0);
  motorGo(1, BRAKEGND, 0);
}



boolean MonsterMotoShieldClass::testCS() {
  return (analogRead(cspin[0]) < CS_THRESHOLD) && (analogRead(cspin[1]) < CS_THRESHOLD);
}

void MonsterMotoShieldClass::motorOff(uint8_t motor) {
  if(!isInit) return;
  motorGo(motor, BRAKEGND, 0);
}

/* motorGo() will set a motor going in a specific direction
 the motor will continue going in that direction, at that speed
 until told to do otherwise.
 
 motor: this should be either 0 or 1, will selet which of the two
 motors to be controlled
 
 direct: Should be between 0 and 3, with the following result
 0: Brake to VCC
 1: Clockwise
 2: CounterClockwise
 3: Brake to GND
 
 pwm: should be a value between 0 and 1023, higher the number, the faster
 it'll go
 
 BRAKEVCC=0 => inApin=HIGH  & inBpin=HIGH
 CW=1       => inApin=HIGH  & inBpin=LOW
 CCW=2      => inApin=LOW   & inBpin=HIGH
 BRAKEGND=3 => inApin=LOW   & inBpin=LOW
 */
void MonsterMotoShieldClass::motorGo(uint8_t motor, uint8_t direct, uint8_t pwm)
{
  if(!isInit) return;
  if (motor <= 1)
  {
    if (direct <=4)
    {
      // Set inA[motor]
      if (direct <=1) // BRAKEVCC = 0, CW   1
        digitalWrite(inApin[motor], HIGH);
      else
        digitalWrite(inApin[motor], LOW);

      // Set inB[motor]
      if ((direct==0)||(direct==2)) // BRAKEVCC = 0, CCW  2
        digitalWrite(inBpin[motor], HIGH);
      else
        digitalWrite(inBpin[motor], LOW);

      analogWrite(pwmpin[motor], pwm<MAXSPEED?pwm:MAXSPEED);
    }
  }
}

MonsterMotoShieldClass MonsterMotoShield=MonsterMotoShieldClass();
/*
int MonsterMotoShieldClass::inApin[] = {7, 4};  // INA: Clockwise input
int MonsterMotoShieldClass::inBpin[] = {8, 9}; // INB: Counter-clockwise input
int MonsterMotoShieldClass::pwmpin[] = {5, 6}; // PWM input
int MonsterMotoShieldClass::cspin[] = {2, 3}; // CS: Current sense ANALOG input
int MonsterMotoShieldClass::enpin[] = {0, 1}; // EN: Status of switches output (Analog pin)
boolean MonsterMotoShieldClass::isInit=false;
*/

