/*
  MonsterMotoShield.h - Library for driving the Monster Moto Shield https://www.sparkfun.com/products/10182

  Inspired of the MonsterMoto Shield Example Sketch coded by: Jim Lindblom, SparkFun Electronics   date: 5/24/11
 
  License: CC-SA 3.0, feel free to use this code however you'd like.
  Please improve upon it! Let me know how you've made it better.
  
  Author: Didier Donsez
  Date : Jan. 12, 2014 
  Tested on RobAIR http://air.imag.fr/index.php/RobAIR/ChassisFlowerPot2WD 
  Tested on Dagu Wild Thumper Chassis http://air.imag.fr/index.php/Wild_Thumper_6WD_Chassis 
*/
#ifndef MonsterMotoShield_h
#define MonsterMotoShield_h

#include "Arduino.h"

// Max PWM speed : should be set to avoid higher voltage when battery voltage (here 12V) is greater then motors voltage (7.2V)
#define MOTOR_VOLTAGE 72
#define BATTERY_VOLTAGE 120
#define MAXSPEED ((MOTOR_VOLTAGE*255)/BATTERY_VOLTAGE)

// Motors
#define LEFT      0
#define RIGHT     1

// H-Bridge mode CW means ClockWise
#define BRAKEVCC 0
#define CW   1
#define CCW  2
#define BRAKEGND 3

// Current Sensor Threshold
#define CS_THRESHOLD 100

class MonsterMotoShieldClass
{
  public:
    MonsterMotoShieldClass();
    void begin();
    void motorsOff();
    void motorOff(uint8_t motor);
    void motorGo(uint8_t motor, uint8_t direct, uint8_t pwm);
    boolean testCS();
 private:
    boolean isInit;
/*  VNH2SP30 pin definitions
 xxx[0] controls '1' outputs
 xxx[1] controls '2' outputs */
    int inApin[2];  // INA: Clockwise input
    int inBpin[2]; // INB: Counter-clockwise input
    int pwmpin[2]; // PWM input
    int cspin[2]; // CS: Current sense ANALOG input
    int enpin[2]; // EN: Status of switches output (Analog pin)
};

extern MonsterMotoShieldClass MonsterMotoShield;

#endif

