/*
 * Demonstration program for the Monster Moto Shield https://www.sparkfun.com/products/10182
 * Can be used with the Android app developed by donmatito http://www.instructables.com/id/Arduino-bot-Android-remote-control/
 */

#include "MonsterMotoShield.h"

int statpin = 13;

int currentSpeed = 5;
int currentDir = CW;

void setup()
{
  Serial.begin(9600);
  
  pinMode(statpin, OUTPUT);

  MonsterMotoShield.begin();
}

void loop() {
  
  testCS();  
  
  // see if there's incoming serial data:
  if (Serial.available() > 0) {
    // read the oldest byte in the serial buffer:
    int incomingByte = Serial.read();
    
    // action depending on the instruction
    // as well as sending a confirmation back to the app
    switch (incomingByte) {

      // commands required by the Android app
      case 'F': // Sent by the Android app
      case 'f':
      case 'u':
        Serial.println("Going forward");
        currentDir=CW;
        MonsterMotoShield.motorGo(LEFT, currentDir, currentSpeed*MAXSPEED/10);
        MonsterMotoShield.motorGo(RIGHT, currentDir, currentSpeed*MAXSPEED/10);
        break;
      case 'R':  // Sent by the Android app
      case 'r':
      case 'j':
        Serial.println("Turning right");
        MonsterMotoShield.motorGo(LEFT, currentDir, currentSpeed*MAXSPEED/10);
        MonsterMotoShield.motorGo(RIGHT, currentDir, (currentSpeed*MAXSPEED*3)/(10*4));
        break;
      case 'L': // Sent by the Android app
      case 'l':
      case 'h':
        Serial.println("Turning left");
        MonsterMotoShield.motorGo(LEFT, currentDir, (currentSpeed*MAXSPEED*3)/(10*4));
        MonsterMotoShield.motorGo(RIGHT, currentDir, currentSpeed*MAXSPEED/10);
        break;
      case 'B':  // Sent by the Android app
      case 'b':
      case 'n':
        Serial.println("Going backwards");
        currentDir=CCW;
        MonsterMotoShield.motorGo(LEFT, currentDir, currentSpeed*MAXSPEED/10);
        MonsterMotoShield.motorGo(RIGHT, currentDir, currentSpeed*MAXSPEED/10);
        break;
      case 'S':  // Sent by the Android app
      case 's':
      case ' ':
        Serial.println("Stopping");
        MonsterMotoShield.motorsOff();
        break;

// Optional commands
      case '<':
        Serial.println("Rotating Left");
        MonsterMotoShield.motorGo(LEFT, CCW, currentSpeed*MAXSPEED/10);
        MonsterMotoShield.motorGo(RIGHT, CW, currentSpeed*MAXSPEED/10);
        break;
      case '>':
        Serial.println("Rotating Right");
        MonsterMotoShield.motorGo(LEFT, CW, currentSpeed*MAXSPEED/10);
        MonsterMotoShield.motorGo(RIGHT, CCW, currentSpeed*MAXSPEED/10);
        break;

// Optional commands
      case 'D':
      case 'd':
        Serial.println("Demo");
        demo();
        break;
        
// Optional commands
      case '1':
        Serial.println("Speed 1");
        currentSpeed=1;
        break;
      case '2':
        Serial.println("Speed 2");
        currentSpeed=2;
        break;
      case '3':
        Serial.println("Speed 3");
        currentSpeed=3;
        break;
      case '4':
        Serial.println("Speed 4");
        currentSpeed=4;
        break;
      case '5':
        Serial.println("Speed 5");
        currentSpeed=5;
        break;
      case '6':
        Serial.println("Speed 6");
        currentSpeed=6;
        break;
      case '7':
        Serial.println("Speed 7");
        currentSpeed=7;
        break;
      case '8':
        Serial.println("Speed 8");
        currentSpeed=8;
        break;
      case '9':
        Serial.println("Speed 9");
        currentSpeed=9;
        break;
      default: 
        // if nothing matches, do nothing
        break;
    }
  }
}


void testCS() {
    if (MonsterMotoShield.testCS())
      digitalWrite(statpin, HIGH);
    else
      digitalWrite(statpin, LOW);
}


void demo()
{
  MonsterMotoShield.motorGo(LEFT, CW, currentSpeed*MAXSPEED/10);
  MonsterMotoShield.motorGo(RIGHT, CW, currentSpeed*MAXSPEED/10);
  if (MonsterMotoShield.testCS()) digitalWrite(statpin, HIGH);
  delay(5000);

  MonsterMotoShield.motorsOff();
  if (MonsterMotoShield.testCS()) digitalWrite(statpin, HIGH);

  delay(1000);

  MonsterMotoShield.motorGo(LEFT, CW, currentSpeed*MAXSPEED/10);
  MonsterMotoShield.motorGo(RIGHT, CCW, currentSpeed*MAXSPEED/10);
  if (MonsterMotoShield.testCS()) digitalWrite(statpin, HIGH);
  delay(2000);

  MonsterMotoShield.motorsOff();
  if (MonsterMotoShield.testCS()) digitalWrite(statpin, HIGH);
}


